import os
from os import environ

from python_anticaptcha import AnticaptchaClient, ImageToTextTask

api_key = environ["KEY"]
DIR = os.path.dirname(os.path.abspath(__file__))
IMAGE = "{}/captcha_ms.jpeg".format(DIR)
EXPECTED_RESULT = "56nn2"


def process(path):
    captcha_fp = open(path, "rb")
    client = AnticaptchaClient(api_key)
    task = ImageToTextTask(captcha_fp)
    job = client.createTaskSmee(task)
    return job.get_captcha_text()


if __name__ == "__main__":
    print("Image: " + IMAGE)
    print("Result: " + str(process(IMAGE)))
    print("Expected: " + str(EXPECTED_RESULT))



import re
import requests
from os import environ

from python_anticaptcha import AnticaptchaClient, NoCaptchaTaskProxylessTask

api_key = environ["KEY"]
site_key_pattern = 'data-sitekey="(.+?)"'
url = "https://www.google.com/recaptcha/api2/demo?invisible=false"
EXPECTED_RESULT = "Verification Success... Hooray!"
client = AnticaptchaClient(api_key)
session = requests.Session()


def get_form_html():
    return session.get(url).text


def get_token(form_html):
    site_key = re.search(site_key_pattern, form_html).group(1)
    task = NoCaptchaTaskProxylessTask(website_url=url, website_key=site_key)
    job = client.createTaskSmee(task, timeout=10 * 60)
    return job.get_solution_response()


def form_submit(token):
    return requests.post(url, data={"g-recaptcha-response": token}).text


def process():
    html = get_form_html()
    token = get_token(html)
    return form_submit(token)


if __name__ == "__main__":
    assert "Verification Success... Hooray!" in process()



import re
import requests
from os import environ
from six.moves.urllib_parse import urljoin
from python_anticaptcha import AnticaptchaClient, RecaptchaV3TaskProxyless

api_key = environ["KEY"]
site_key_pattern = "grecaptcha.execute\('(.+?)'"
action_name_pattern = "\{action: '(.+?)'\}"
url = "https://recaptcha-demo.appspot.com/recaptcha-v3-request-scores.php"
client = AnticaptchaClient(api_key)
session = requests.Session()


def get_form_html():
    return session.get(url).text


def get_token(form_html):
    website_key = re.search(site_key_pattern, form_html).group(1)
    page_action = re.search(action_name_pattern, form_html).group(1)
    task = RecaptchaV3TaskProxyless(
        website_url=url, website_key=website_key, page_action=page_action, min_score=0.7
    )
    job = client.createTask(task)
    job.join(maximum_time=9 * 60)
    return [page_action, job.get_solution_response()]


def form_submit(page_action, token):
    return requests.post(
        url=urljoin(url, "recaptcha-v3-verify.php"),
        params={"action": page_action, "token": token},
    ).json()


def process():
    html = get_form_html()
    [page_action, token] = get_token(html)
    return form_submit(page_action, token)


if __name__ == "__main__":
    result = process()
    assert result["success"] is True
    print("Processed successfully")



import six
from python_anticaptcha.exceptions import InvalidWidthException, MissingNameException


class BaseField(object):
    label = None
    labelHint = None

    def serialize(self, name=None):
        data = {}
        if self.label:
            data["label"] = self.label or False
        if self.labelHint:
            data["labelHint"] = self.labelHint or False
        return data


class NameBaseField(BaseField):
    name = None

    def serialize(self, name=None):
        data = super(NameBaseField, self).serialize(name)
        if name:
            data["name"] = name
        elif self.name:
            data["name"] = self.name
        else:
            raise MissingNameException(cls=self.__class__)
        return data


class SimpleText(BaseField):
    contentType = "text"

    def __init__(self, content, label=None, labelHint=None, width=None):
        self.label = label
        self.labelHint = labelHint

        self.content = content
        self.width = width

    def serialize(self, name=None):
        data = super(SimpleText, self).serialize(name)
        data["contentType"] = self.contentType
        data["content"] = self.content

        if self.width:
            if self.width not in [100, 50, 33, 25]:
                raise InvalidWidthException(self.width)
            data["inputOptions"] = {}
            data["width"] = self.width
        return data


class Image(BaseField):
    contentType = "image"

    def __init__(self, imageUrl, label=None, labelHint=None):
        self.label = label
        self.labelHint = labelHint
        self.imageUrl = imageUrl

    def serialize(self, name=None):
        data = super(Image, self).serialize(name)
        data["contentType"] = self.contentType
        data["content"] = self.imageUrl
        return data


class WebLink(BaseField):
    contentType = "link"

    def __init__(self, linkText, linkUrl, label=None, labelHint=None, width=None):
        self.label = label
        self.labelHint = labelHint

        self.linkText = linkText
        self.linkUrl = linkUrl

        self.width = width

    def serialize(self, name=None):
        data = super(WebLink, self).serialize(name)
        data["contentType"] = self.contentType

        if self.width:
            if self.width not in [100, 50, 33, 25]:
                raise InvalidWidthException(self.width)
            data["inputOptions"] = {}
            data["width"] = self.width

        data.update({"content": {"url": self.linkUrl, "text": self.linkText}})

        return data


class TextInput(NameBaseField):
    def __init__(self, placeHolder=None, label=None, labelHint=None, width=None):
        self.label = label
        self.labelHint = labelHint

        self.placeHolder = placeHolder

        self.width = width

    def serialize(self, name=None):
        data = super(TextInput, self).serialize(name)
        data["inputType"] = "text"

        data["inputOptions"] = {}

        if self.width:
            if self.width not in [100, 50, 33, 25]:
                raise InvalidWidthException(self.width)

            data["inputOptions"]["width"] = str(self.width)

        if self.placeHolder:
            data["inputOptions"]["placeHolder"] = self.placeHolder
        return data


class Textarea(NameBaseField):
    def __init__(
        self, placeHolder=None, rows=None, label=None, width=None, labelHint=None
    ):
        self.label = label
        self.labelHint = labelHint

        self.placeHolder = placeHolder
        self.rows = rows
        self.width = width

    def serialize(self, name=None):
        data = super(Textarea, self).serialize(name)
        data["inputType"] = "textarea"
        data["inputOptions"] = {}
        if self.rows:
            data["inputOptions"]["rows"] = str(self.rows)
        if self.placeHolder:
            data["inputOptions"]["placeHolder"] = self.placeHolder
        if self.width:
            data["inputOptions"]["width"] = str(self.width)
        return data


class Checkbox(NameBaseField):
    def __init__(self, text, label=None, labelHint=None):
        self.label = label
        self.labelHint = labelHint

        self.text = text

    def serialize(self, name=None):
        data = super(Checkbox, self).serialize(name)
        data["inputType"] = "checkbox"
        data["inputOptions"] = {"label": self.text}
        return data


class Select(NameBaseField):
    type = "select"

    def __init__(self, label=None, choices=None, labelHint=None):
        self.label = label
        self.labelHint = labelHint
        self.choices = choices or ()

    def get_choices(self):
        for choice in self.choices:
            if isinstance(choice, six.text_type):
                yield choice, choice
            else:
                yield choice

    def serialize(self, name=None):
        data = super(Select, self).serialize(name)
        data["inputType"] = self.type

        data["inputOptions"] = []
        for value, caption in self.get_choices():
            data["inputOptions"].append({"value": value, "caption": caption})

        return data


class Radio(Select):
    type = "radio"


class ImageUpload(NameBaseField):
    def __init__(self, label=None, labelHint=None):
        self.label = label
        self.labelHint = labelHint

    def serialize(self, name=None):
        data = super(ImageUpload, self).serialize(name)
        data["inputType"] = "imageUpload"
        return data



import base64
from .fields import BaseField


class BaseTask(object):
    def serialize(self, **result):
        return result


class ProxyMixin(BaseTask):
    def __init__(self, *args, **kwargs):
        self.proxyType = kwargs.pop("proxy_type")
        self.userAgent = kwargs.pop("user_agent")
        self.proxyAddress = kwargs.pop("proxy_address")
        self.proxyPort = kwargs.pop("proxy_port")
        self.proxyLogin = kwargs.pop("proxy_login")
        self.proxyPassword = kwargs.pop("proxy_password")

        self.cookies = kwargs.pop("cookies", "")
        super(ProxyMixin, self).__init__(*args, **kwargs)

    def serialize(self, **result):
        result = super(ProxyMixin, self).serialize(**result)
        result["userAgent"] = self.userAgent
        result["proxyType"] = self.proxyType
        result["proxyAddress"] = self.proxyAddress
        result["proxyPort"] = self.proxyPort
        if self.proxyLogin:
            result["proxyLogin"] = self.proxyLogin
            result["proxyPassword"] = self.proxyPassword
        if self.cookies:
            result["cookies"] = self.cookies
        return result


class NoCaptchaTaskProxylessTask(BaseTask):
    type = "NoCaptchaTaskProxyless"
    websiteURL = None
    websiteKey = None
    websiteSToken = None
    recaptchaDataSValue = None

    def __init__(
        self,
        website_url,
        website_key,
        website_s_token=None,
        is_invisible=None,
        recaptcha_data_s_value=None,
    ):
        self.websiteURL = website_url
        self.websiteKey = website_key
        self.websiteSToken = website_s_token
        self.recaptchaDataSValue = recaptcha_data_s_value
        self.isInvisible = is_invisible

    def serialize(self):
        data = {
            "type": self.type,
            "websiteURL": self.websiteURL,
            "websiteKey": self.websiteKey,
        }
        if self.websiteSToken is not None:
            data["websiteSToken"] = self.websiteSToken
        if self.isInvisible is not None:
            data["isInvisible"] = self.isInvisible
        if self.recaptchaDataSValue is not None:
            data["recaptchaDataSValue"] = self.recaptchaDataSValue
        return data


class NoCaptchaTask(ProxyMixin, NoCaptchaTaskProxylessTask):
    type = "NoCaptchaTask"


class FunCaptchaProxylessTask(BaseTask):
    type = "FunCaptchaTaskProxyless"
    websiteURL = None
    websiteKey = None

    def __init__(self, website_url, website_key, *args, **kwargs):
        self.websiteURL = website_url
        self.websiteKey = website_key
        super(FunCaptchaProxylessTask, self).__init__(*args, **kwargs)

    def serialize(self, **result):
        result = super(FunCaptchaProxylessTask, self).serialize(**result)
        result.update(
            {
                "type": self.type,
                "websiteURL": self.websiteURL,
                "websitePublicKey": self.websiteKey,
            }
        )
        return result


class FunCaptchaTask(ProxyMixin, NoCaptchaTaskProxylessTask):
    type = "FunCaptchaTask"


class ImageToTextTask(object):
    type = "ImageToTextTask"
    fp = None
    phrase = None
    case = None
    numeric = None
    math = None
    minLength = None
    maxLength = None

    def __init__(
        self,
        fp,
        phrase=None,
        case=None,
        numeric=None,
        math=None,
        min_length=None,
        max_length=None,
    ):
        self.fp = fp
        self.phrase = phrase
        self.case = case
        self.numeric = numeric
        self.math = math
        self.minLength = min_length
        self.maxLength = max_length

    def serialize(self):
        return {
            "type": self.type,
            "body": base64.b64encode(self.fp.read()).decode("utf-8"),
            "phrase": self.phrase,
            "case": self.case,
            "numeric": self.numeric,
            "math": self.math,
            "minLength": self.minLength,
            "maxLength": self.maxLength,
        }


class CustomCaptchaTask(BaseTask):
    type = "CustomCaptchaTask"
    imageUrl = None
    assignment = None
    form = None

    def __init__(self, imageUrl, form=None, assignment=None):
        self.imageUrl = imageUrl
        self.form = form or {}
        self.assignment = assignment

    def serialize(self):
        data = super(CustomCaptchaTask, self).serialize()
        data.update({"type": self.type, "imageUrl": self.imageUrl})
        if self.form:
            forms = []
            for name, field in self.form.items():
                if isinstance(field, BaseField):
                    forms.append(field.serialize(name))
                else:
                    field = field.copy()
                    field["name"] = name
                    forms.append(field)
            data["forms"] = forms
        if self.assignment:
            data["assignment"] = self.assignment
        return data


class RecaptchaV3TaskProxyless(BaseTask):
    type = "RecaptchaV3TaskProxyless"
    websiteURL = None
    websiteKey = None
    minScore = None
    pageAction = None

    def __init__(self, website_url, website_key, min_score, page_action):
        self.websiteURL = website_url
        self.websiteKey = website_key
        self.minScore = min_score
        self.pageAction = page_action

    def serialize(self):
        data = super(RecaptchaV3TaskProxyless, self).serialize()
        data["type"] = self.type
        data["websiteURL"] = self.websiteURL
        data["websiteKey"] = self.websiteKey
        data["minScore"] = self.minScore
        data["pageAction"] = self.pageAction
        return data


class HCaptchaTaskProxyless(BaseTask):
    type = "HCaptchaTaskProxyless"
    websiteURL = None
    websiteKey = None

    def __init__(self, website_url, website_key):
        self.websiteURL = website_url
        self.websiteKey = website_key

    def serialize(self):
        data = super(HCaptchaTaskProxyless, self).serialize()
        data["type"] = self.type
        data["websiteURL"] = self.websiteURL
        data["websiteKey"] = self.websiteKey
        return data


class HCaptchaTask(ProxyMixin, HCaptchaTaskProxyless):
    type = "HCaptchaTask"


class SquareNetTask(BaseTask):
    type = "SquareNetTask"
    fp = None
    objectName = None
    rowsCount = None
    columnsCount = None

    def __init__(self, fp, objectName, rowsCount, columnsCount):
        self.fp = fp
        self.objectName = objectName
        self.rowsCount = rowsCount
        self.columnsCount = columnsCount

    def serialize(self):
        data = super(SquareNetTask, self).serialize()
        data["type"] = self.type
        data["body"] = base64.b64encode(self.fp.read()).decode("utf-8")
        data["objectName"] = self.objectName
        data["rowsCount"] = self.rowsCount
        data["columnsCount"] = self.columnsCount
        return data



import time
from os import environ

from python_anticaptcha import AnticaptchaClient, NoCaptchaTaskProxylessTask

api_key = environ["KEY"]
invisible_captcha = True
url = "https://www.google.com/recaptcha/api2/demo?invisible={}".format(
    str(invisible_captcha)
)
EXPECTED_RESULT = "Verification Success... Hooray!"
client = AnticaptchaClient(api_key)


def get_token(url, site_key, invisible):
    task = NoCaptchaTaskProxylessTask(
        website_url=url, website_key=site_key, is_invisible=invisible
    )
    job = client.createTask(task)
    job.join(maximum_time=60 * 15)
    return job.get_solution_response()


def process(driver):
    driver.get(url)
    site_key = get_sitekey(driver)
    print("Found site-key", site_key)
    token = get_token(url, site_key, invisible_captcha)
    print("Found token", token)
    form_submit(driver, token)
    return driver.find_element_by_class_name("recaptcha-success").text


def form_submit(driver, token):
    driver.execute_script(
        "document.getElementById('g-recaptcha-response').innerHTML='{}';".format(token)
    )
    driver.execute_script("onSuccess('{}')".format(token))
    time.sleep(1)


def get_sitekey(driver):
    return driver.find_element_by_class_name("g-recaptcha").get_attribute(
        "data-sitekey"
    )


if __name__ == "__main__":
    from selenium.webdriver import Firefox
    from selenium.webdriver.firefox.options import Options

    options = Options()
    # options.add_argument('-headless')
    driver = Firefox(firefox_options=options)
    assert EXPECTED_RESULT in process(driver)



import six

if six.PY3:

    def split(value, sep, maxsplit):
        return value.split(sep, maxsplit=maxsplit)


else:

    def split(value, sep, maxsplit):
        parts = value.split(sep)
        return parts[:maxsplit] + [
            sep.join(parts[maxsplit:]),
        ]



import os
from collections import OrderedDict
from unittest import TestCase, skipIf

import six

from python_anticaptcha import TextInput, Select, AnticaptchaClient
from python_anticaptcha.tasks import CustomCaptchaTask, NoCaptchaTaskProxylessTask


class CustomCaptchaTaskTestCase(TestCase):
    def test_serialize(self):
        form = OrderedDict()
        form["dot_count"] = TextInput(
            label="Dot count", labelHint="Enter the number of dots."
        )
        form["dot_color"] = Select(
            label="Dot color",
            labelHint="Select the color of dots.",
            choices=[("red", "Red"), ("blue", "Blue"), ("green", "Green")],
        )
        form["license_plate"] = {
            "label": "Number",
            "labelHint": False,
            "contentType": False,
            "inputType": "text",
            "inputOptions": {
                "width": "100",
                "placeHolder": "Enter a letters and number without spaces",
            },
        }
        task = CustomCaptchaTask(
            imageUrl="https://s.jawne.info.pl/dot_img",
            assignment="Count the dots and indicate their color.",
            form=form,
        )
        expected_result = {
            "type": "CustomCaptchaTask",
            "assignment": "Count the dots and indicate their color.",
            "imageUrl": "https://s.jawne.info.pl/dot_img",
            "forms": [
                {
                    "labelHint": "Enter the number of dots.",
                    "inputType": "text",
                    "inputOptions": {},
                    "name": "dot_count",
                    "label": "Dot count",
                },
                {
                    "labelHint": "Select the color of dots.",
                    "inputType": "select",
                    "inputOptions": [
                        {"caption": "Red", "value": "red"},
                        {"caption": "Blue", "value": "blue"},
                        {"caption": "Green", "value": "green"},
                    ],
                    "name": "dot_color",
                    "label": "Dot color",
                },
                {
                    "label": "Number",
                    "labelHint": False,
                    "contentType": False,
                    "name": "license_plate",
                    "inputType": "text",
                    "inputOptions": {
                        "width": "100",
                        "placeHolder": "Enter a letters and number without spaces",
                    },
                },
            ],
        }
        self.assertSequenceEqual(
            sorted(task.serialize().keys()), sorted(expected_result.keys())
        )
        for result, expected in zip(
            task.serialize()["forms"], expected_result["forms"]
        ):
            self.assertSequenceEqual(sorted(result.keys()), sorted(expected.keys()))
            self.assertDictEqual(result, expected)
        self.assertSequenceEqual(task.serialize()["forms"], expected_result["forms"])
        self.assertDictEqual(task.serialize(), expected_result)



from .base import AnticaptchaClient
from pkg_resources import get_distribution, DistributionNotFound
from .tasks import (
    NoCaptchaTask,
    NoCaptchaTaskProxylessTask,
    FunCaptchaTask,
    FunCaptchaProxylessTask,
    RecaptchaV3TaskProxyless,
    HCaptchaTask,
    HCaptchaTaskProxyless,
    SquareNetTask,
    ImageToTextTask,
    CustomCaptchaTask,
)
from .exceptions import AnticaptchaException
from .fields import (
    SimpleText,
    Image,
    WebLink,
    TextInput,
    Textarea,
    Checkbox,
    Select,
    Radio,
    ImageUpload,
)

AnticatpchaException = AnticaptchaException

try:
    __version__ = get_distribution(__name__).version
except DistributionNotFound:
    # package is not installed
    pass



from __future__ import unicode_literals
from os import environ

import time
from python_anticaptcha.base import SLEEP_EVERY_CHECK_FINISHED
from python_anticaptcha import AnticaptchaClient
from python_anticaptcha.fields import Radio
from python_anticaptcha.tasks import CustomCaptchaTask

api_key = environ["KEY"]

"""
Note:
If you all of the content will be porn/violence, then we'd better make another task type with age filter for workers.
If it is like 1% or less, then no worries, send as CustomCaptchaTask
Reference: Ticket #16426 of Anti-captcha.com
"""


CHOICES_CONTENT = [("P", "Porn / Nudity"), ("V", "Violence"), ("O", "Other")]
URLS = [
    "https://s.jawne.info.pl/captcha-nude",
    "https://s.jawne.info.pl/captcha-violence",
    "https://s.jawne.info.pl/captcha-mona-lisa",
]

RESULTS = ["P", "V", "O"]

form = {
    "content": Radio(
        label="Content classification",
        labelHint="What is visible in the picture?",
        choices=CHOICES_CONTENT,
    )
}


def build_jobs(urls):
    client = AnticaptchaClient(api_key)
    tasks = [
        CustomCaptchaTask(imageUrl=url, assignment="Content moderation", form=form)
        for url in urls
    ]
    return [client.createTask(task) for task in tasks]


def process_bulk(urls):
    jobs = build_jobs(urls)
    [job.join(maximum_time=60 * 10) for job in jobs]
    return [job.get_answers()["content"] for job in jobs]


def process_bulk_iter(urls):
    jobs = list(enumerate(build_jobs(urls)))
    done = []
    while len(jobs) != len(done):
        time.sleep(SLEEP_EVERY_CHECK_FINISHED)

        for i, job in jobs:
            if job in done:
                continue

            if job.check_is_ready():
                yield urls[i], job.get_answers()["content"]
                done.append(job)


if __name__ == "__main__":
    result_map = dict(zip(URLS, RESULTS))
    for url, result in process_bulk_iter(URLS):
        print("{} -> {} (expected: {})".format(url, result, result_map[url]))
    print("Finished!")



from unittest import TestCase

from python_anticaptcha.fields import (
    SimpleText,
    Image,
    WebLink,
    Textarea,
    Checkbox,
    Select,
    Radio,
    ImageUpload,
    TextInput,
)


class SimpleTextTestCase(TestCase):
    def test_serialize(self):
        form = SimpleText(label="name", labelHint="subtitle", content="content")

        self.assertEqual(
            form.serialize(),
            {
                "label": "name",
                "labelHint": "subtitle",
                "contentType": "text",
                "content": "content",
            },
        )


class ImageTestCase(TestCase):
    def test_serialize(self):
        form = Image(
            label="title",
            labelHint="subtitle",
            imageUrl="https://s.jawne.info.pl/dot_img",
        )

        self.assertEqual(
            form.serialize(),
            {
                "label": "title",
                "labelHint": "subtitle",
                "contentType": "image",
                "content": "https://s.jawne.info.pl/dot_img",
            },
        )


class WebLinkTestCase(TestCase):
    def test_serialize(self):
        form = WebLink(
            label="title",
            labelHint="subtitle",
            linkText="text",
            linkUrl="https://s.jawne.info.pl/dot_img",
        )

        self.assertEqual(
            form.serialize(name="link"),
            {
                "label": "title",
                "labelHint": "subtitle",
                "contentType": "link",
                "content": {"url": "https://s.jawne.info.pl/dot_img", "text": "text"},
            },
        )


class TextInputTestCase(TestCase):
    def test_serialize(self):
        form = TextInput(
            label="title", labelHint="subtitle", placeHolder="hint", width=50
        )

        self.assertDictEqual(
            form.serialize(name="name",),
            {
                "label": "title",
                "labelHint": "subtitle",
                "name": "name",
                "inputType": "text",
                "inputOptions": {"width": "50", "placeHolder": "hint"},
            },
        )


class TextareaTestCase(TestCase):
    def test_serialize(self):
        form = Textarea(
            label="title", labelHint="subtitle", width=50, rows=25, placeHolder="hint"
        )
        self.assertEqual(
            form.serialize(name="name"),
            {
                "label": "title",
                "labelHint": "subtitle",
                "name": "name",
                "inputType": "textarea",
                "inputOptions": {"width": "50", "rows": "25", "placeHolder": "hint"},
            },
        )


class CheckboxTestCase(TestCase):
    def test_serialize(self):
        form = Checkbox(label="title", labelHint="subtitle", text="checkbox")
        self.assertEqual(
            form.serialize(name="name"),
            {
                "label": "title",
                "labelHint": "subtitle",
                "name": "name",
                "inputType": "checkbox",
                "inputOptions": {"label": "checkbox"},
            },
        )


class SelectTestCase(TestCase):
    def test_serialize(self):
        form = Select(
            label="title", labelHint="subtitle", choices=[("value", "caption"),]
        )
        self.assertEqual(
            form.serialize(name="name"),
            {
                "label": "title",
                "labelHint": "subtitle",
                "name": "name",
                "inputType": "select",
                "inputOptions": [{"value": "value", "caption": "caption"}],
            },
        )


class RadioTestCase(TestCase):
    def test_serialize(self):
        form = Radio(
            label="title", labelHint="subtitle", choices=[("value", "caption"),]
        )
        self.assertEqual(
            form.serialize(name="name"),
            {
                "label": "title",
                "labelHint": "subtitle",
                "name": "name",
                "inputType": "radio",
                "inputOptions": [{"value": "value", "caption": "caption"}],
            },
        )


class ImageUploadTestCase(TestCase):
    def test_serialize(self):
        form = ImageUpload(label="title", labelHint="subtitle")
        self.assertEqual(
            form.serialize(name="name"),
            {
                "label": "title",
                "labelHint": "subtitle",
                "name": "name",
                "inputType": "imageUpload",
            },
        )



import requests
from os import environ

from python_anticaptcha import AnticaptchaClient, ImageToTextTask

api_key = environ["KEY"]

URL = "https://raw.githubusercontent.com/ad-m/python-anticaptcha/master/examples/captcha_ms.jpeg"
EXPECTED_RESULT = "56nn2"


def process(url):
    session = requests.Session()
    client = AnticaptchaClient(api_key)
    task = ImageToTextTask(session.get(url, stream=True).raw)
    job = client.createTask(task)
    job.join()
    return job.get_captcha_text()


if __name__ == "__main__":
    print("URL: " + URL)
    print("Result: " + str(process(URL)))
    print("Expected: " + str(EXPECTED_RESULT))



import os
import re
import requests
from os import environ
from six.moves.urllib_parse import urljoin
from python_anticaptcha import AnticaptchaClient, SquareNetTask

api_key = environ["KEY"]
client = AnticaptchaClient(api_key)
session = requests.Session()
DIR = os.path.dirname(os.path.abspath(__file__))
filename = "{}/square.png".format(DIR)
objectName = "cat"
size = [3, 3]
EXPECTED_RESULT = [0, 4, 5, 8]


def get_image(filename):
    return open(filename, "rb")


def get_solution(fp, objectName, size):
    task = SquareNetTask(
        fp=fp, objectName=objectName, rowsCount=size[0], columnsCount=size[1],
    )
    job = client.createTask(task)
    job.join(maximum_time=9 * 60)
    return job.get_cells_numbers()


def process():
    fp = get_image(filename)
    solution = get_solution(fp, objectName, size)
    return solution


if __name__ == "__main__":
    result = process()
    print("Result: " + str(result))
    print("Expected: " + str(EXPECTED_RESULT))
    assert len(result) == len(EXPECTED_RESULT)
    for x in range(len(EXPECTED_RESULT)):
        assert result[x] is EXPECTED_RESULT[x]
    print("Processed successfully")



import os
import re
import requests
from os import environ
from six.moves.urllib_parse import urljoin
from python_anticaptcha import AnticaptchaClient, SquareNetTask
from concurrent.futures import ThreadPoolExecutor


api_key = environ["KEY"]
client = AnticaptchaClient(api_key)
session = requests.Session()
DIR = os.path.dirname(os.path.abspath(__file__))
filename = "{}/square.png".format(DIR)
objectName = "cat"
size = [3, 3]
EXPECTED_RESULT = [0, 4, 5, 8]

submitted_task = 100


def compare(a, b):
    return len(a) == len(b) and all(a[x] == b[x] for x in range(len(a)))


def create_task():
    fp = open(filename, "rb")
    task = SquareNetTask(
        fp=fp, objectName=objectName, rowsCount=size[0], columnsCount=size[1],
    )
    return client.createTask(task)


def validate_solution(job):
    job.join()
    solution = job.get_cells_numbers()
    return compare(solution, EXPECTED_RESULT)


if __name__ == "__main__":
    with ThreadPoolExecutor(max_workers=10) as e:
        # create captcha task request
        job_futures = [e.submit(create_task) for x in range(submitted_task)]
        # fetch result for each captcha task request
        result_futures = [e.submit(validate_solution, f.result()) for f in job_futures]
        result = [f.result() for f in result_futures]

        ratio = sum(1 for x in result if x) / submitted_task
        # ratio achieved is around 0.75
        print("Success ratio: ", (ratio))



import requests
import time
import json
import warnings

from .compat import split
from six.moves.urllib_parse import urljoin
from .exceptions import AnticaptchaException

SLEEP_EVERY_CHECK_FINISHED = 3
MAXIMUM_JOIN_TIME = 60 * 5


class Job(object):
    client = None
    task_id = None
    _last_result = None

    def __init__(self, client, task_id):
        self.client = client
        self.task_id = task_id

    def _update(self):
        self._last_result = self.client.getTaskResult(self.task_id)

    def check_is_ready(self):
        self._update()
        return self._last_result["status"] == "ready"

    def get_solution_response(self):  # Recaptcha
        return self._last_result["solution"]["gRecaptchaResponse"]

    def get_token_response(self):  # Funcaptcha
        return self._last_result["solution"]["token"]

    def get_answers(self):
        return self._last_result["solution"]["answers"]

    def get_captcha_text(self):  # Image
        return self._last_result["solution"]["text"]

    def get_cells_numbers(self):
        return self._last_result["solution"]["cellNumbers"]

    def report_incorrect(self):
        warnings.warn(
            "report_incorrect is deprecated, use report_incorrect_image instead",
            DeprecationWarning,
        )
        return self.client.reportIncorrectImage()

    def report_incorrect_image(self):
        return self.client.reportIncorrectImage(self.task_id)

    def report_incorrect_recaptcha(self):
        return self.client.reportIncorrectRecaptcha(self.task_id)

    def join(self, maximum_time=None):
        elapsed_time = 0
        maximum_time = maximum_time or MAXIMUM_JOIN_TIME
        while not self.check_is_ready():
            time.sleep(SLEEP_EVERY_CHECK_FINISHED)
            elapsed_time += SLEEP_EVERY_CHECK_FINISHED
            if elapsed_time is not None and elapsed_time > maximum_time:
                raise AnticaptchaException(
                    None,
                    250,
                    "The execution time exceeded a maximum time of {} seconds. It takes {} seconds.".format(
                        maximum_time, elapsed_time
                    ),
                )


class AnticaptchaClient(object):
    client_key = None
    CREATE_TASK_URL = "/createTask"
    TASK_RESULT_URL = "/getTaskResult"
    BALANCE_URL = "/getBalance"
    REPORT_IMAGE_URL = "/reportIncorrectImageCaptcha"
    REPORT_RECAPTCHA_URL = "/reportIncorrectRecaptcha"
    SOFT_ID = 847
    language_pool = "en"
    response_timeout = 5

    def __init__(
        self, client_key, language_pool="en", host="api.anti-captcha.com", use_ssl=True
    ):
        self.client_key = client_key
        self.language_pool = language_pool
        self.base_url = "{proto}://{host}/".format(
            proto="https" if use_ssl else "http", host=host
        )
        self.session = requests.Session()

    @property
    def client_ip(self):
        if not hasattr(self, "_client_ip"):
            self._client_ip = self.session.get(
                "https://api.myip.com", timeout=self.response_timeout
            ).json()["ip"]
        return self._client_ip

    def _check_response(self, response):
        if response.get("errorId", False) == 11:
            response[
                "errorDescription"
            ] = "{} Your missing IP address is propably {}.".format(
                response["errorDescription"], self.client_ip
            )
        if response.get("errorId", False):
            raise AnticaptchaException(
                response["errorId"], response["errorCode"], response["errorDescription"]
            )

    def createTask(self, task):
        request = {
            "clientKey": self.client_key,
            "task": task.serialize(),
            "softId": self.SOFT_ID,
            "languagePool": self.language_pool,
        }
        response = self.session.post(
            urljoin(self.base_url, self.CREATE_TASK_URL),
            json=request,
            timeout=self.response_timeout,
        ).json()
        self._check_response(response)
        return Job(self, response["taskId"])

    def createTaskSmee(self, task, timeout=MAXIMUM_JOIN_TIME):
        """
        Beta method to stream response from smee.io
        """
        response = self.session.head(
            "https://smee.io/new", timeout=self.response_timeout
        )
        smee_url = response.headers["Location"]
        task = task.serialize()
        request = {
            "clientKey": self.client_key,
            "task": task,
            "softId": self.SOFT_ID,
            "languagePool": self.language_pool,
            "callbackUrl": smee_url,
        }
        r = self.session.get(
            url=smee_url,
            headers={"Accept": "text/event-stream"},
            stream=True,
            timeout=(self.response_timeout, timeout),
        )
        response = self.session.post(
            url=urljoin(self.base_url, self.CREATE_TASK_URL),
            json=request,
            timeout=self.response_timeout,
        ).json()
        self._check_response(response)
        for line in r.iter_lines():
            content = line.decode("utf-8")
            if '"host":"smee.io"' not in content:
                continue
            payload = json.loads(split(content, ":", 1)[1].strip())
            if "taskId" not in payload["body"] or str(payload["body"]["taskId"]) != str(
                response["taskId"]
            ):
                continue
            r.close()
            if task["type"] == "CustomCaptchaTask":
                payload["body"]["solution"] = payload["body"]["data"][0]
            job = Job(client=self, task_id=response["taskId"])
            job._last_result = payload["body"]
            return job

    def getTaskResult(self, task_id):
        request = {"clientKey": self.client_key, "taskId": task_id}
        response = self.session.post(
            urljoin(self.base_url, self.TASK_RESULT_URL), json=request
        ).json()
        self._check_response(response)
        return response

    def getBalance(self):
        request = {"clientKey": self.client_key}
        response = self.session.post(
            urljoin(self.base_url, self.BALANCE_URL), json=request
        ).json()
        self._check_response(response)
        return response["balance"]

    def reportIncorrectImage(self, task_id):
        request = {"clientKey": self.client_key, "taskId": task_id}
        response = self.session.post(
            urljoin(self.base_url, self.REPORT_IMAGE_URL), json=request
        ).json()
        self._check_response(response)
        return response.get("status", False) != False

    def reportIncorrectRecaptcha(self, task_id):
        request = {"clientKey": self.client_key, "taskId": task_id}
        response = self.session.post(
            urljoin(self.base_url, self.REPORT_RECAPTCHA_URL), json=request
        ).json()
        self._check_response(response)
        return response["status"] == "success"



class AnticaptchaException(Exception):
    def __init__(self, error_id, error_code, error_description, *args):
        super(AnticaptchaException, self).__init__(
            "[{}:{}]{}".format(error_code, error_id, error_description)
        )
        self.error_description = error_description
        self.error_id = error_id
        self.error_code = error_code


AnticatpchaException = AnticaptchaException


class InvalidWidthException(AnticaptchaException):
    def __init__(self, width):
        self.width = width
        msg = "Invalid width (%s). Can be one of these: 100, 50, 33, 25." % (
            self.width,
        )
        super(InvalidWidthException, self).__init__("AC-1", 1, msg)


class MissingNameException(AnticaptchaException):
    def __init__(self, cls):
        self.cls = cls
        msg = 'Missing name data in {0}. Provide {0}.__init__(name="X") or {0}.serialize(name="X")'.format(
            str(self.cls)
        )
        super(MissingNameException, self).__init__("AC-2", 2, msg)



from collections import OrderedDict
from os import environ

from python_anticaptcha import AnticaptchaClient
from python_anticaptcha.fields import TextInput, Select, Radio
from python_anticaptcha.tasks import CustomCaptchaTask

api_key = environ["KEY"]

URL = "https://s.jawne.info.pl/dot_img"
EXPECTED_RESULT = ("7", "red")

CHOICES = [("red", "Red"), ("blue", "Blue"), ("green", "Green")]

CHOICES_COUNTRY = [
    ("VE", "Venezuela"),
    ("IN", "India"),
    ("US", "United States"),
    ("MA", "Morocco"),
    ("BD", "Bangladesh"),
    ("PH", "Philippines"),
    ("ID", "Indonesia"),
    ("RU", "Russia"),
    ("VN", "Vietnam"),
    ("UA", "Ukraine"),
    ("CA", "Canada"),
    ("Other", "Other"),
]

CHOICES_GENRE = [("M", "Male"), ("F", "Female"), ("O", "Other")]

form = OrderedDict()
form["dot_count"] = TextInput(label="Dot count", labelHint="Enter the number of dots.")
form["dot_color"] = Select(
    label="Dot color", labelHint="Select the color of dots.", choices=CHOICES
)

form["country"] = Select(
    label="Your country",
    labelHint="Select your country of origin",
    choices=CHOICES_COUNTRY,
)
form["genre"] = Radio(
    label="Your genre", labelHint="Select your genre", choices=CHOICES_GENRE
)


def process(url):
    client = AnticaptchaClient(api_key)
    task = CustomCaptchaTask(
        imageUrl=url, assignment="Count the dots and indicate their color.", form=form
    )
    job = client.createTaskSmee(task)
    answer = job.get_answers()
    return answer["dot_count"], answer["dot_color"]


if __name__ == "__main__":
    print("ImageUrl: " + URL)
    print("Result: " + str(process(URL)))
    print("Expected: " + str(EXPECTED_RESULT))



from urllib.parse import urlparse

import requests
from os import environ
import re
from random import choice

from python_anticaptcha import AnticaptchaClient, FunCaptchaTask

api_key = environ["KEY"]
site_key_pattern = 'data-pkey="(.+?)"'
url = "https://www.funcaptcha.com/demo/"
client = AnticaptchaClient(api_key)
session = requests.Session()

UA = (
    "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_10_1) AppleWebKit/537.36 "
    "(KHTML, like Gecko) Chrome/39.0.2171.95 Safari/537.36"
)
session.headers = {"User-Agent": UA}
proxy_urls = environ["PROXY_URL"].split(",")


def parse_url(url):
    parsed = urlparse(url)
    return dict(
        proxy_type=parsed.scheme,
        proxy_address=parsed.hostname,
        proxy_port=parsed.port,
        proxy_login=parsed.username,
        proxy_password=parsed.password,
    )


def get_form_html():
    return session.get(url).text


def get_token(form_html):
    proxy_url = choice(proxy_urls)
    proxy = parse_url(proxy_url)

    site_key = re.search(site_key_pattern, form_html).group(1)
    task = FunCaptchaTask(url, site_key, proxy=proxy, user_agent=UA)
    job = client.createTask(task)
    job.join(maximum_time=10 ** 4)
    return job.get_token_response()


def process():
    html = get_form_html()
    return get_token(html)


if __name__ == "__main__":
    print(process())



# -*- coding: utf-8 -*-
from unittest import TestCase, skipIf
from retry import retry

import os

from python_anticaptcha import AnticatpchaException

_multiprocess_can_split_ = True


def missing_key(*args, **kwargs):
    return skipIf(
        "KEY" not in os.environ,
        "Missing KEY environment variable. " "Unable to connect Anti-captcha.com",
    )(*args, **kwargs)


@missing_key
class CustomDotTestCase(TestCase):
    # For unknown reasons, workers are not always
    # able to count correctly. ¯\_(ツ)_/¯
    @retry(tries=3)
    def test_process_dot(self):
        from examples import custom_dot

        self.assertEqual(custom_dot.process(custom_dot.URL), custom_dot.EXPECTED_RESULT)


@missing_key
class CustomModerationTestCase(TestCase):
    # unexperienced workers make mistakes
    @retry(tries=6)
    def test_process_bulk_iter(self):
        from examples import custom_moderation

        self.assertSequenceEqual(
            sorted(list(custom_moderation.process_bulk_iter(custom_moderation.URLS))),
            sorted(zip(custom_moderation.URLS, custom_moderation.RESULTS)),
        )

    # unexperienced workers make mistakes
    @retry(tries=6)
    def test_process_bulk(self):
        from examples import custom_moderation

        self.assertEqual(
            custom_moderation.process_bulk(custom_moderation.URLS),
            custom_moderation.RESULTS,
        )


@missing_key
@skipIf("PROXY_URL" not in os.environ, "Missing PROXY_URL environment variable")
class FuncaptchaTestCase(TestCase):
    # CI Proxy is unstable.
    # Occasionally fails, so I repeat my attempt to have others selected.
    @retry(tries=3)
    def test_funcaptcha(self):
        from examples import funcaptcha

        self.assertTrue(funcaptcha.process())


@missing_key
class RecaptchaRequestTestCase(TestCase):
    # Anticaptcha responds is not fully reliable.
    @retry(tries=6)
    def test_process(self):
        from examples import recaptcha_request

        self.assertIn(recaptcha_request.EXPECTED_RESULT, recaptcha_request.process())


@missing_key
class RecaptchaV3TestCase(TestCase):
    # Anticaptcha responds is not fully reliable.
    @retry(tries=3)
    def test_process(self):
        from examples import recaptcha3_request

        self.assertTrue(recaptcha3_request.process()["success"])


@missing_key
class RecaptchaSeleniumtTestCase(TestCase):
    # Anticaptcha responds is not fully reliable.
    @retry(tries=6)
    def test_process(self):
        from examples import recaptcha_selenium
        from selenium.webdriver import Firefox
        from selenium.webdriver.firefox.options import Options
        from selenium.webdriver import FirefoxProfile

        options = Options()
        options.add_argument("-headless")

        ffprofile = FirefoxProfile()
        ffprofile.set_preference("intl.accept_languages", "en-US")

        driver = Firefox(firefox_profile=ffprofile, firefox_options=options)
        self.assertIn(
            recaptcha_selenium.EXPECTED_RESULT, recaptcha_selenium.process(driver)
        )
        driver.quit()


@missing_key
class TextTestCase(TestCase):
    def test_process(self):
        from examples import text

        self.assertEqual(text.process(text.IMAGE).lower(), text.EXPECTED_RESULT.lower())


@missing_key
class HCaptchaTaskProxylessTestCase(TestCase):
    @retry(tries=3)
    def test_process(self):
        from examples import hcaptcha_request

        self.assertIn(hcaptcha_request.EXPECTED_RESULT, hcaptcha_request.process())


@missing_key
class HCaptchaTaskProxylessTestCase(TestCase):
    def test_process(self):
        from examples import hcaptcha_request

        self.assertIn(
            "Your request have submitted successfully.", hcaptcha_request.process()
        )


@missing_key
class SquareNetTask(TestCase):
    # For unknown reasons, workers are not always
    # able to count correctly. ¯\_(ツ)_/¯
    @retry(tries=10)
    def test_process(self):
        from examples import squarenet

        self.assertCountEqual(squarenet.EXPECTED_RESULT, squarenet.process())



import re
import requests
from os import environ

from python_anticaptcha import AnticaptchaClient, HCaptchaTaskProxyless

api_key = environ["KEY"]
site_key_pattern = 'data-sitekey="(.+?)"'
url = "http://hcaptcha.jawne.info.pl/"
client = AnticaptchaClient(api_key)
session = requests.Session()
EXPECTED_RESULT = "Your request have submitted successfully."


def get_form_html():
    return session.get(url).text


def get_token(form_html):
    site_key = re.search(site_key_pattern, form_html).group(1)
    task = HCaptchaTaskProxyless(website_url=url, website_key=site_key)
    job = client.createTask(task)
    job.join()
    return job.get_solution_response()


def form_submit(token):
    return requests.post(url, data={"g-recaptcha-response": token}).text


def process():
    html = get_form_html()
    token = get_token(html)
    return form_submit(token)


if __name__ == "__main__":
    assert EXPECTED_RESULT in process()



from urllib.parse import urlparse, quote

import requests
from os import environ
import re
from random import choice
from selenium.webdriver.common.by import By
from selenium.webdriver.support.ui import WebDriverWait
from selenium.webdriver.support import expected_conditions as EC

from python_anticaptcha import AnticaptchaClient, FunCaptchaTask

api_key = environ["KEY"]
site_key_pattern = 'public_key: "(.+?)",'
url = "https://client-demo.arkoselabs.com/solo-animals"
client = AnticaptchaClient(api_key)

proxy_urls = environ["PROXY_URL"].split(",")


def parse_url(url):
    parsed = urlparse(url)
    return dict(
        proxy_type=parsed.scheme,
        proxy_address=parsed.hostname,
        proxy_port=parsed.port,
        proxy_login=parsed.username,
        proxy_password=parsed.password,
    )


def get_token(public_key, user_agent):
    proxy_url = choice(proxy_urls)
    proxy = parse_url(proxy_url)
    task = FunCaptchaTask(url, public_key, user_agent=user_agent, **proxy)
    job = client.createTask(task)
    job.join(maximum_time=10 ** 4)
    return job.get_token_response()


def process(driver):
    driver.get(url)
    public_key = re.search(site_key_pattern, driver.page_source).group(1)
    print("Found public-key", public_key)
    user_agent = driver.execute_script("return navigator.userAgent;")
    token = get_token(public_key, user_agent)
    print("Received token", token)
    script = """
    document.getElementById('FunCaptcha-Token').value = decodeURIComponent('{0}');
    document.getElementById('verification-token').value = decodeURIComponent('{0}');
    document.getElementById('submit-btn').disabled = false;
    """.format(
        quote(token)
    )
    driver.execute_script(script)
    driver.find_element(By.ID, "submit-btn").click()
    return driver.page_source


if __name__ == "__main__":
    from selenium.webdriver import Firefox
    from selenium.webdriver.firefox.options import Options

    options = Options()
    # options.add_argument('-headless')
    driver = Firefox(firefox_options=options)
    assert "Solved!" in process(driver)



from setuptools import setup
from codecs import open
from os import path, system
import sys

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, "README.rst"), encoding="utf-8") as f:
    long_description = f.read()


tests_deps = ["nose", "retry", "selenium"]

extras = {"tests": tests_deps, "docs": "sphinx"}

setup(
    name="python-anticaptcha",
    description="Client library for solve captchas with Anticaptcha.com support.",
    long_description=long_description,
    url="https://github.com/ad-m/python-anticaptcha",
    author="Adam Dobrawy",
    author_email="anticaptcha@jawnosc.tk",
    license="MIT",
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
    test_suite="tests",
    use_scm_version=True,
    setup_requires=["setuptools_scm", "wheel"],
    keywords="recaptcha captcha development",
    packages=["python_anticaptcha"],
    install_requires=["requests", "six"],
    tests_require=tests_deps,
    extras_require=extras,
)
